<?php 
	/*
	*	basic_view_ead.php - Inline Contentdm Viewer for EAD .xml files. 
	*
	*	Author: 	Nathan Pugh - Marriott Library Applications Programming - The University of Utah
	*	Date:	2008-02-08
	*
	*	Requirements:	This ABSOLUTELY REQUIRES PHP5 or up.
	*					Written for Contentdm v4.3, this file should be compatible with all 4.x versions.
	*
	*					This view uses PHP's XSLT support to apply an XSL Transform to the EAD-spec .xml file - the item 
	*					from Contentdm.  This is built in to PHP5.  PHP's XSLT support may not be installed 
	*					( usually it is but isn't enabled by default ).  For more information see: http://php.net/manual/en/ref.xslt.php
	*
	*					It is expected that this file will be included from within CDM's basic_view.php, after some logic 
	*					to determine that this is indeed an EAD xpec XML file.  As such, it relies on certain variables to 
	*					already be defined in the global namespace: 
	*						- $alias		 - The current collection's cdm alias, starting with a slash.  ( e.g. /my-collection )
	*						- $filename	- Contentdm's external, overt filename for the xml file, with or without the path.  By 
	*							default the path is included in $filename at this point in basic_view.php
	*
	*					The assumption is being made that the xsl transforms will be in the directory specified in $xsl_dir.  
	*					Feel free to change this to match your setup.
	*/
	
	// Profiling for the XSL transform.  If set to true this will add an HTML comment to the page source that 
	//	displays how much time the XSL processor required to apply the transform.
	define("XSLT_PROFILING", false);		
	
	// $xsl_dir: The directory to find xsl transforms in, minus the trailing slash.
	$xsl_dir = INCLUDE_PATH . '/xsl';				
	
	// $xsl_filename: Filename of the xsl transform to apply.  This will be appended to $xsl_dir to get the real file path of the .xsl transform
	$xsl_filename = 'ss-committee-cdm.xsl';
	
	// Set up the path to the EAD .xml file this item contains. This relies on CDM's current internal directory 
	// structure for a collection, which puts all items in the 'image' directory.
	$col_name = $col_path = '';
	dmGetCollectionParameters($alias, $col_name, $col_path);
	$path_xml = $col_path . DIRECTORY_SEPARATOR . 'image' . DIRECTORY_SEPARATOR . basename($filename);
	
	// TODO: Any custom logic you may require to implement dynamically selecting a xsl transform, say choosing a 
	// different transform per collection, would go here. 
	// 
	// END TODO: ( custom stylesheet logic )

	// $doc_xml and $doc_xsl:	DOMDocument objects used to load XML/XSL data from the item and stylesheet, respectively.
	$doc_xml = new DOMDocument(); 
	$doc_xsl = new DOMDocument();
	
	// $xsl_stylesheet_loaded:	This will be set to true when the XSL transform has been successfully applied.  
	$xsl_transform_successful = false;
	
	// $output:	The string to display.  This will the transformed XML or an error message should there be any problems.
	$output = "";
	
	// Load the xml file
	if( $doc_xml->load($path_xml) )
	{
		// Load the xsl stylesheet
		if( $doc_xsl->load($xsl_dir . DIRECTORY_SEPARATOR . $xsl_filename) ) 
		{
			// Create a new XSLTProcessor and apply the transform.
			$xslt_proc = new XSLTProcessor;
			$xslt_proc->importStyleSheet($doc_xsl);
			if( XSLT_PROFILING ) { $time_start = microtime(true); }	// XSLT profiling - Get start timestamp
			if( $tmp = $xslt_proc->transformToXML($doc_xml) )
			{
				if( XSLT_PROFILING ) { $time_end = microtime(true); }	// XSLT profiling - Get finished timestamp
				$xsl_transform_successful = true;
				$output .= $tmp;
				// XSLT profiling - Add the profiling message as a HTML comment.
				if( XSLT_PROFILING ) { $output .= "<!-- XSL Transform applied in " . (float)($time_end-$time_start) . " seconds. -->"; }
			}
		} // end if ( xsl document loaded )
		if( !$xsl_transform_successful )
		{
			// Unable to load the specified XSL transform.  Add an error message and dump the raw XML to the output.
			$output .= "<b>Unable to load the stylesheet for this item.  The raw XML will be displayed.</b><br /><br />";
			$output .=  $doc_xml->saveXML();
		}
	} // end if ( xml document loaded )
	else
	{
		// The XML document failed to load. 
		$output .= "<h3>Unable to display this item.</h3>";
	}
?>
<style type="text/css">
	/* This will display in the middle of a contentdm td element which, by default, is set to text-align: center. */ 
	.ead_document{ text-align: left; }
</style>
<div class="ead_document">
	<?php echo $output; ?>
</div>